%global ghc_version 6.10.1

%global pkg_libdir %{_libdir}/ghc-%{ghc_version}/%{name}-%{version}
%global pkg_docdir %{_docdir}/ghc/libraries/%{name}-%{version}

%bcond_without doc
%bcond_without prof

# ghc does not emit debug information
%global debug_package %{nil}

Name:           haddock
Version:        2.4.1
Release:        4%{?dist}
Summary:        Haskell documentation tool

Group:          Development/Tools
License:        BSD
URL:            http://www.haskell.org/haddock/
Source0:        http://hackage.haskell.org/packages/archive/%{name}/%{version}/%{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
# fedora ghc archs:
ExclusiveArch:  %{ix86} x86_64 ppc alpha
BuildRequires:  ghc = %{ghc_version}
Buildrequires:  ghc-ghc-paths-devel
%if %{with doc}
BuildRequires:  libxslt, docbook-style-xsl, autoconf
BuildRequires:  ghc-doc = %{ghc_version}
%endif
%if %{with prof}
BuildRequires:  ghc-prof = %{ghc_version}
BuildRequires:  ghc-ghc-paths-prof
%endif

%description
Haddock is a tool for automatically generating hyperlinked documentation from
annotated Haskell source code. It is primary intended for documenting
libraries, but it is useful for any kind of Haskell code.

Haddock lets you write documentation annotations next to the definitions of
functions and types in the source code in a lightweight syntax.


%package -n ghc-%{name}-devel
Summary:        Haskell source documentation library
Group:          Development/Libraries
Requires:       ghc = %{ghc_version}
Obsoletes:      ghc-haddock < 2.4.1-4
Obsoletes:      ghc682-haddock < 2.0.0.0-3
Requires(post): ghc = %{ghc_version}
Requires(preun): ghc = %{ghc_version}

%description -n ghc-%{name}-devel
Libraries for working with Haddock from Haskell code.

%if %{with doc}
%package -n ghc-%{name}-doc
Summary: Documentation for %{name}
Group: Development/Libraries
Requires: ghc-doc = %{ghc_version}
Requires(post): ghc-doc = %{ghc_version}
Requires(postun): ghc-doc = %{ghc_version}

%description -n ghc-%{name}-doc
This package contains development documentation files for the %{name} library.
%endif


%if %{with prof}
%package -n ghc-%{name}-prof
Summary:        Profiling libraries for %{name}
Group:          Development/Libraries
Requires:       ghc-%{name}-devel = %{version}-%{release}
Requires:       ghc-prof = %{ghc_version}

%description -n ghc-%{name}-prof
This package contains profiling libraries for %{name}.
%endif


%prep
%setup -q


%build
%cabal_configure --ghc %{!?without_prof:-p}
%cabal build
%if %{with doc}
%cabal haddock
cd doc
test -f configure || autoreconf
./configure
make html
cd -
%endif
%ghc_gen_scripts


%install
rm -rf $RPM_BUILD_ROOT
%cabal_install
%ghc_install_scripts
%ghc_gen_filelists ghc-%{name}

# version since haddock is also in ghc now
mv ${RPM_BUILD_ROOT}/%{_bindir}/haddock{,-%{version}}


%clean
rm -rf $RPM_BUILD_ROOT

%post
semanage fcontext -a -t unconfined_execmem_exec_t %{_bindir}/%{name} >/dev/null 2>&1
restorecon %{_bindir}/%{name}

%post -n ghc-%{name}-devel
%ghc_register_pkg


%if %{with doc}
%post -n ghc-%{name}-doc
%ghc_reindex_haddock
%endif


%preun -n ghc-%{name}-devel
if [ "$1" -eq 0 ] ; then
  %ghc_unregister_pkg
fi


%if %{with doc}
%postun -n ghc-%{name}-doc
if [ "$1" -eq 0 ] ; then
  %ghc_reindex_haddock
fi
%endif


%files
%defattr(-,root,root,-)
%doc CHANGES LICENSE README
%{_bindir}/haddock-%{version}
%{_datadir}/haddock-%{version}


%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%defattr(-,root,root,-)


%if %{with doc}
%files -n ghc-%{name}-doc
%defattr(-,root,root,-)
%{pkg_docdir}
%doc doc/haddock/*
%endif


%if %{with prof}
%files -n ghc-%{name}-prof -f ghc-%{name}-prof.files
%defattr(-,root,root,-)
%endif


%changelog
* Mon Mar  9 2009 Jens Petersen <petersen@redhat.com> - 2.4.1-4
- update to cabal2spec-0.12:
  - use global and bcond
  - arch list
  - ghc-paths is renamed to ghc-ghc-paths
- devel subpackage obsoletes old library subpackage
- move docs to doc subpackage

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Dec 23 2008 Jens Petersen <petersen@redhat.com> - 2.4.1-2
- buildrequire ghc-paths
- no longer need haddock-2.4.1-no-ghc-paths.patch

* Mon Dec 15 2008 Jens Petersen <petersen@redhat.com> - 2.4.1-1
- update to 2.4.1 release needed for gtk2hs
- update source url
- drop coreutils and autoconf from buildrequires
- add haddock-2.4.1-no-ghc-paths.patch to workaround no ghc-paths package yet
- provide devel package
- use rpm macros to build and package
- version haddock program since it is also in ghc
- buildrequire autoconf

* Thu Jun 26 2008 Jens Petersen <petersen@redhat.com> - 2.0.0.0-3.fc10
- drop ghcver subpackage in line with ghc
- obsolete ghc682-haddock
- add haddock-2.0.0.0-ghc683-process.patch to fix build with ghc-6.8.3

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.0.0.0-2
- Autorebuild for GCC 4.3

* Mon Jan  7 2008 Bryan O'Sullivan <bos@serpentine.com> - 2.0.0.0-1
- Update to 2.0.0.0, add library packages

* Thu Dec 20 2007 Bryan O'Sullivan <bos@serpentine.com> - 0.9-2
- Exclude alpha, ppc64

* Thu Dec 20 2007 Bryan O'Sullivan <bos@serpentine.com> - 0.9-1
- update to 0.9

* Thu Aug 16 2007 Jens Petersen <petersen@redhat.com>
- update License field

* Fri Nov  3 2006 Jens Petersen <petersen@redhat.com> - 0.8-1
- update to 0.8
- use new cabal build system
- update file list
- buildrequire autoconf

* Thu Sep 28 2006 Jens Petersen <petersen@redhat.com> - 0.7-4
- rebuild for FC6

* Fri Jun 30 2006 Jens Petersen <petersen@redhat.com> - 0.7-3
- set selinux unconfined_execmem_exec_t context to allow running under
  targeted policy (#195821)

* Thu Mar  2 2006 Jens Petersen <petersen@redhat.com> - 0.7-2
- rebuild

* Tue Sep 27 2005 Jens Petersen <petersen@redhat.com> - 0.7-1
- cleanup for Fedora Extras (Gérard Milmeister)
  - drop versioned binary
  - set standard buildroot
- do not create debuginfo
- improve the description

* Mon Aug 22 2005 Jens Petersen <petersen@redhat.com>
- 0.7 release

* Tue Jul  5 2005 Jens Petersen <petersen@haskell.org> - 0.7-0.20050705
- update to cvs snapshot
  - update filelist
  - install data files in a subdir

* Wed Dec 15 2004 Jens Petersen <petersen@haskell.org>
- spec file cleanup
- only generate docs in html

* Sat Oct 11 2003 Sven Panne <sven_panne@yahoo.com>
- Include architecture-independent files in file list

* Tue Aug 26 2003 Sven Panne <sven_panne@yahoo.com>
- Use autoreconf instead of autoconf

* Mon Jul 28 2003 Sven Panne <sven_panne@yahoo.com>
- Updated to version 0.5
- Automagically generate configure if it is not there

* Tue Jul 23 2002 Simon Marlow <simonmar@microsoft.com>
- Updated to version 0.4

* Sun Jun 23 2002 Sven Panne <sven_panne@yahoo.com>
- Cleaned up build root handling and added more docs

* Wed May 01 2002 Tom Moertel <tom-rpms@moertel.com>
- Created spec file
